@@ -78,7 +78,7 @@ def clean_old_artifacts(overview, configuration, stacks, stack, credentials, **k
 @a_task(needs_stack=True, needs_credentials=True)
 def confirm_deployment(overview, configuration, stacks, stack, credentials, **kwargs):
     """Confirm deployment via SNS notification for each instance"""
-    log.info("All stacks have been confirmed to be deployed!")
+    Builder().confirm_deployment(stack, credentials)
 
 @a_task(needs_stack=True)
 def sanity_check(overview, configuration, stacks, stack, **kwargs):
